<?php
/*
Plugin Name: World Weather Widget
Plugin URI: http://blog.titacgs.com.ar/world-weather-plugin-para-wp/
Description: This plugin/widget allows you to insert weather status in your sidebar. It connects to World Weather Online to get weather forecasts.
Version: 1.0
Author: Vanessa Gutiérrez
Author URI: http://www.titacgs.com.ar/
License: This plugin is released under the GPLv2 license. The images packaged with this plugin are the property of
their respective owners, and do not, necessarily, inherit the GPLv2 license.
*/

/**
 * Register the Widget
 */
add_action('widgets_init', 'world_weather_widget_register');
function world_weather_widget_register() {
	register_widget('World_Weather_Widget');
}

//add_action( 'admin_init', 'wowe_js_admin_init' );
add_action('admin_print_scripts', 'wowe_js_admin_init');

 function wowe_js_admin_init() {
	/* Register our script. */
	// wp_register_script( 'myPluginScript', WP_PLUGIN_URL . '/myPlugin/script.js' );
	wp_enqueue_script( 'wowe', plugins_url('js/wowe.js', __FILE__) );
}


add_action('wp_ajax_get_location', 'get_location_ajax');
add_action('wp_ajax_nopriv_get_location', 'get_location_ajax');

function get_location_ajax() {
	$location = $_GET['location'];
	
	global $wpdb;
	$site_url = $wpdb->get_results('SELECT option_value FROM wp_options WHERE option_name = "widget_worldweather"');		
	$site_url = unserialize($site_url[0]->option_value);
	$apikey = $site_url[3]['apikey'];
	if(empty($apikey)) {
		$apikey = 'e9a33a76e4232506112002';
	}
	
	$url = 'http://www.worldweatheronline.com/feed/search.ashx?key='.$apikey.'&query='.urlencode($location).'&format=json';
	$wowe = wp_remote_get($url);
	$wowe = json_decode($wowe['body']);
	$wowe = $wowe->search_api->result;
	
	$html = '';
	foreach($wowe as $result) {
		$html.='<option value="'.urlencode($result->areaName[0]->value).','.urlencode($result->country[0]->value).'">'.$result->areaName[0]->value.', '.$result->country[0]->value.'</option>';
	}
	
	echo $html;
}

/**
 * The Widget Class
 */
 
if ( !class_exists('World_Weather_Widget') ) {
class World_Weather_Widget extends WP_Widget {

	function World_Weather_Widget() {
		$widget_ops = array( 'description' => __('Displays weather forecast', 'wowe') );
		$this->WP_Widget( 'worldweather', __('World Weather', 'wowe'), $widget_ops );
	}
	
	function wowe_fields_array( $instance = array() ) {
		
		return array(
			'wtitle' => array(
				'title' => __('Title', 'wowe'),
				'comment' => __('', 'wowe'),
				'ftype' => 'simple-input',
			),
			'apikey' => array(
				'title' => __('API Key', 'wowe'),
				'comment' => __('If you do not have an API Key go to http://www.worldweatheronline.com/register.aspx and sign up to get one.', 'wowe'),
				'ftype' => 'simple-input',
			),
			'flocation' => array(
				'title' => __('Find Location', 'wowe'),
				'comment' => __('Search by City or Town name.', 'wowe'),
				'ftype' => 'search-input',
				'blabel' => __('Search', 'wowe'),
			),
			'slocation' => array(
				'title' => __('Select Location', 'wowe'),
				'comment' => __('Select one location from the results available.', 'wowe'),
				'ftype' => 'select',
			),
		);
	}

	function widget($args, $instance) {
		
		extract($args);
		
		$instance = wp_parse_args($instance, array(
			'title' => '',
			'icon_set' => 'default',
			'size' => '48x48'
		) );
		
		echo $before_widget;
		
		
		if ( !empty( $instance['wtitle'] ) )
			echo $before_title . $instance['wtitle'] . $after_title;
			
		if ( empty($instance['apikey']) )
			$instance['apikey'] = 'e9a33a76e4232506112002';
			
		$url = 'http://www.worldweatheronline.com/feed/weather.ashx?q='.$instance['slocation'].'&format=json&num_of_days=2&key='.$instance['apikey'];
		
		$wowe = wp_remote_get($url);
		$wowe = json_decode($wowe['body']);
?>
	<div id="temp_actual" ><?php echo $wowe->data->current_condition[0]->temp_C ?>°</div>
	<div id="temp_max">Max <?php echo $wowe->data->weather[0]->tempMaxC; ?>°</div>
    <div id="temp_min">Min <?php echo $wowe->data->weather[0]->tempMinC; ?>°</div>
<?php
		
		echo $after_widget;
		
	}

	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	function form($instance) {
		global $wpdb;
		
		$site_url = $wpdb->get_results('SELECT option_value FROM wp_options WHERE option_name = "siteurl"');		
		$site_url = $site_url[0]->option_value;
		
		$instance = wp_parse_args($instance, array(
			'title' => '',
		) );
?>		
		<p><?php _e('Enter your API Key and select your location.', 'wowe'); ?></p>
		
<?php

		foreach ( $this->wowe_fields_array( $instance ) as $key => $data ) {
			echo '<p>';
			printf( '<label for="%s"> %s: %s</label><br/> ', esc_attr( $this->get_field_id($key) ), esc_attr( $data['title'] ), esc_attr( $data['comment'] ) );
			switch($data['ftype']) {
				case 'simple-input':
					printf( '<input id="%s" name="%s" value="%s" style="%s" />', esc_attr( $this->get_field_id($key) ), esc_attr( $this->get_field_name($key) ), esc_attr( $instance[$key] ), 'width:65%;' );
					break;
				case 'search-input':
					printf( '<input id="fweather" name="fweather" value="type a country" /> <input id="locsearch" type="button" value="%s" >', $data['blabel']);
					break;
				case 'select':
					printf( '<select id="select-weather" name="%s" style="%s" /><option value="%s">%s</option></select>', esc_attr( $this->get_field_name($key) ), 'width:65%;', urlencode(esc_attr( $instance[$key] )), urldecode(esc_attr( $instance[$key] )));
					break;
			}
			echo '</p>' . "\n";
		}

	}
	
}
}
